/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ftp;

import java.net.URL;

import org.eclipse.ftp.internal.*;

/**
 * From this class, you can create FTP clients
 * for transferring data to and from an FTP server.
 * 
 * <p>
 * <b>Note:</b> This class/interface is part of an interim API that is still under 
 * development and expected to change significantly before reaching stability. 
 * It is being made available at this early stage to solicit feedback from pioneering 
 * adopters on the understanding that any code that uses this API will almost 
 * certainly be broken (repeatedly) as the API evolves.
 * </p>
 */
public class Ftp {

	/**
	 * Create a client that can be used to transfer data to and from an FTP server.
	 * @param url a url of the form ftp://host:port/path
	 * @return an FTP client
	 * @throws FtpException
	 */
	public static IClient createClient(URL url) throws FtpException {
		validateUrl(url);
		FTPServerLocation location = new FTPServerLocation(url);
		return new FTPClient(location, null, new IFTPClientListener() {
			public void responseReceived(int responseCode, String responseText) {
				if (FtpPlugin.DEBUG_RESPONSES) {
					System.out.println(responseCode + " " + responseText); //$NON-NLS-1$
				}
			}
			public void requestSent(String command, String argument) {
				if (FtpPlugin.DEBUG_REQUESTS) {
					System.out.println(command + " " + argument); //$NON-NLS-1$
				}
			}
		});
	}

	/**
	 * Validate that the given URL identifies an ftp server.
	 * @param url a url that is potentially being used to connect to an ftp server
	 */
	public static void validateUrl(URL url) throws FtpException {
		if (!url.getProtocol().equals("ftp")) { //$NON-NLS-1$
			throw new FtpException(FtpPlugin.getResourceString("Ftp.0", url.toExternalForm()), IFtpStatus.INVALID_URL_PROTOCOL); //$NON-NLS-1$
		}
	}
}
