/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target;

import org.eclipse.swt.widgets.Shell;


/**
 * Listener for recieving target events.
 * @see org.eclipse.target.ISiteManager
 */
public interface ITargetListener {
	
	/**
	 * Callback indicating that a site has been added to the site manager.
	 * @param site the added site
	 */
	public void siteAdded(Site site);
	
	/**
	 * Callback indicating that a site has been removed from the site manager.
	 * @param site the removed site
	 */
	public void siteRemoved(Site site);
	
	/**
	 * Callback invoked when a site is about to be removed.
	 * Returning <code>false</code> will cause the removal to be aborted.
	 * @param sites the sites being removed
	 * @param shell a shell that can be used to parent a prompt
	 * @return <code>true</code> if the removal can proceed
	 */
	public boolean aboutToRemove(Site[] sites, Shell shell);
}
