/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.iofile;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.target.ITargetResource;
import org.eclipse.target.Site;
import org.eclipse.ui.IMemento;

public class IoFileSite extends Site {

	/* (non-Javadoc)
	 * @see org.eclipse.target.Site#save(org.eclipse.ui.IMemento)
	 */
	public void save(IMemento memento) {
		// Nothing to save
	}

	/* (non-Javadoc)
	 * @see org.eclipse.target.Site#init(org.eclipse.ui.IMemento)
	 */
	protected void init(IMemento memento) {
		// Nothing to save
	}

	/* (non-Javadoc)
	 * @see org.eclipse.target.Site#getRootResource()
	 */
	public ITargetResource getRootResource() {
		return new IoFileTargetResource(this, new File(getLocation()), "");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.target.Site#canBeReached(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public boolean canBeReached(IProgressMonitor monitor) throws CoreException {
		return true;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.target.Site#toUrl()
	 */
	public URL toUrl() {
		try {
			return new URL(getLocation());
		} catch (MalformedURLException e) {
			// This return statement is never reached
			return null;
		}
	}

}
