/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.registry;

import java.util.*;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.ui.model.AdaptableList;

public class SiteCreationWizardsRegistry extends RegistryReader {

	public static final String PT_SITE_CREATION_WIZARDS ="siteCreationWizards"; //$NON-NLS-1$
	
	protected final static String TAG_WIZARD = "wizard"; //$NON-NLS-1$

	private Map wizards = new HashMap();
	
	/* (non-Javadoc)
	 * @see org.eclipse.target.internal.registry.RegistryReader#readElement(org.eclipse.core.runtime.IConfigurationElement)
	 */
	protected boolean readElement(IConfigurationElement element) {
		if (element.getName().equals(TAG_WIZARD)) {
			String descText = getDescription(element);
			SiteWizardDescriptor desc = new SiteWizardDescriptor(element, descText);
			wizards.put(desc.getId(), desc);
			return true;
		}
		return false;
	}
	
	public AdaptableList asAdaptableList() {
		AdaptableList list = new AdaptableList();
		for (Iterator iter = wizards.values().iterator(); iter.hasNext();) {
			list.add((IAdaptable)iter.next());
		}
		return list;
	}

}
