/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.registry;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.target.Site;
import org.eclipse.ui.internal.WorkbenchPlugin;

/**
 * This class provides access to a form description as
 * contributed to a form in a plugin's manifest (plugin.xml).
 * A form contains a set of form field descriptors.
 */
public class SiteDescriptor {

	public  static final String ATT_ID = "id"; //$NON-NLS-1$
	public  static final String ATT_TYPE = "type"; //$NON-NLS-1$
	public  static final String ATT_CLASS = "class"; //$NON-NLS-1$
	
	private final IConfigurationElement element;
	private String id;
	private String type;
	private String descText;

	public SiteDescriptor(IConfigurationElement element, String descText) {
		this.element = element;
		this.descText = descText;
		loadFromExtension();
	}

	private void loadFromExtension() {
		id = element.getAttribute(ATT_ID);
		type = element.getAttribute(ATT_TYPE);
	}
	
	public Site createSite() throws CoreException {
		Object obj = WorkbenchPlugin.createExtension(element, ATT_CLASS);
		((Site)obj).setDescriptor(this);
		return (Site) obj;
	}
	
	public String getId() {
		return id;
	}

	public String getDescription() {
		return descText;
	}
	
	public String getType() {
		return type;
	}
}
