/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.window.Window;
import org.eclipse.target.ITargetResource;
import org.eclipse.target.internal.Utils;
import org.eclipse.target.internal.ui.TargetAction;
import org.eclipse.target.internal.ui.TargetFolderSelectionDialog;

/**
 * Action that copies resources from one site to another
 */
public class CopyAction extends TargetAction {

	/* (non-Javadoc)
	 * @see org.eclipse.target.internal.ui.TargetAction#isEnabled()
	 */
	protected boolean isEnabled() throws CoreException {
		return getSelectedResources().length > 0;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		final ITargetResource[] resources = getSelectedResources();
		if (resources.length == 0) return;
		TargetFolderSelectionDialog dialog = new TargetFolderSelectionDialog(getShell(), new TargetFolderSelectionDialog.IEnablementChecker() {
			public boolean isEnabledFor(ITargetResource folder) {
				return verifyNoOverlap(folder, resources);
			}
		});
		int code = dialog.open();
		if (code == Window.OK) {
			performCopy(resources, dialog.getSelectedFolder());
		}
	}

	protected boolean verifyNoOverlap(ITargetResource folder, ITargetResource[] resources) {
		for (int i = 0; i < resources.length; i++) {
			ITargetResource resource = resources[i];
			if (resource.getFullPath().startsWith(folder.getFullPath()) || folder.getFullPath().startsWith(resource.getFullPath())) {
				return false;
			}
		}
		return true;
	}

	private void performCopy(final ITargetResource[] resources, final ITargetResource selectedFolder) {
		try {
			new CopyOperation(getTargetPart(), selectedFolder, resources).run();
		} catch (InvocationTargetException e) {
			Utils.handle(getShell(), e);
		} catch (InterruptedException e) {
			// Ignore
		}
	}
}
