/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.ui;

import org.eclipse.target.ITargetResource;
import org.eclipse.ui.part.IPageBookViewPage;

/**
 * A page that can be used to display the contents of an {@link ITargetContainer}.
 * The page is created using an {@link org.eclipse.target.ui.ISitePageDescriptor}.
 * 
 * <p>
 * Note: clients shoudl not implement this interface directly but instead should implement
 * {@link SitePage}.
 * 
 * <p>
 * <b>Note:</b> This class/interface is part of an interim API that is still under 
 * development and expected to change significantly before reaching stability. 
 * It is being made available at this early stage to solicit feedback from pioneering 
 * adopters on the understanding that any code that uses this API will almost 
 * certainly be broken (repeatedly) as the API evolves.
 * </p>
 * 
 * @see org.eclipse.target.ui.ISitePageDescriptor
 * @see org.eclipse.target.ui.SitePage
 */
public interface ISitePage extends IPageBookViewPage {
	
	/**
	 * Set the input of the page to the given container. The contents of
	 * the container will be displayed by the page.
	 * @param container the container whose contents are to be displayed
	 */
	void setInput(ITargetResource container);
	
	/**
	 * Return the resource being displayed by the page.
	 * @return the resource being displayed by the page
	 */
	ITargetResource getInput();
}
